@@ -92,7 +92,9 @@ class StepPMXPrepareSimulations(StepPMXBase, BaseModel):
         """
         Works out where to get starting structure from based on the current run and simulation type
         """
-        if self.run_type == _PSE.RBFE:
+        if self.get_additional_setting(_PSE.PREV_STEP) is not None:
+            return self.get_additional_setting(_PSE.PREV_STEP)
+        elif self.run_type == _PSE.RBFE:
             if sim_type == "nvt":
                 return "em"
             elif sim_type == "eq":
