@@ -45,22 +45,16 @@ class StepPMXPrepareTransitions(StepPMXBase, BaseModel):
         trr = "{0}/traj.trr".format(eqpath)
         frame = "{0}/frame.gro".format(tipath)
 
-        trjconv_args = [
-            "-s",
-            tpr,
-            "-f",
-            trr,
-            "-o",
-            frame,
-            "-sep",
-            "-ur",
-            "compact",
-            "-pbc",
-            "mol",
-            "-b",
-            # use the first 2ns as equilibration time
-            2000,
-        ]
+        trjconv_args = {
+            "-s": tpr,
+            "-f": trr,
+            "-o": frame,
+            "-sep": "",
+            "-ur": "compact",
+            "-pbc": "mol",
+            "-b": 2000,
+        }
+        trjconv_args = self.get_arguments(trjconv_args)
         self._gromacs_executor.execute(
             _GE.TRJCONV, arguments=trjconv_args, pipe_input="echo System"
         )
@@ -95,12 +89,13 @@ class StepPMXPrepareTransitions(StepPMXBase, BaseModel):
             state=state,
             sim_type="transitions",
             framestart=1,
-            framestop=81
+            framestop=81,
         )
         if result.returncode != 0:
             self._logger.log(f"WARNING, grompp has failed in {tipath}", _LE.WARNING)
             for line in result.stderr.split("\n"):
                 self._logger.log(line, _LE.DEBUG)
+        self._clean_backup_files(tipath)
 
     def prepare_transitions(self, jobs: List[str]):
         for edge in jobs:
