@@ -26,7 +26,9 @@ class StepPMXSetup(StepPMXBase, BaseModel):
 
     def __init__(self, **data):
         super().__init__(**data)
-        self._gromacs_executor = GromacsExecutor(prefix_execution=_SGE.GROMACS_LOAD)
+        self._gromacs_executor = GromacsExecutor(
+            prefix_execution=self.execution.prefix_execution
+        )
 
     def execute(self):
         # sets the number of replicas to be used throughput the pmx run
