@@ -1,5 +1,4 @@
 from icolos.core.flow_control.iterator import StepIterator
-from icolos.core.workflow_steps.prediction.active_learning import StepActiveLearning
 from icolos.utils.enums.step_enums import StepBaseEnum
 
 _SBE = StepBaseEnum
@@ -10,6 +9,5 @@ class FlowControlInitializationEnum:
     # Keep these separate to the main pool of steps to avoid circular imports
 
     FLOW_CONTROL_INIT_DICT = {
-        _SBE.STEP_ACTIVE_LEARNING: StepActiveLearning,
         _SBE.STEP_ITERATOR: StepIterator,
     }
