@@ -431,7 +431,7 @@ class OpenBabelEnum:
         "-opdbqt"
     )
     OBABEL_OUTPUT_FORMAT_SDF = "-osdf"  # sets the output format to "SDF"
-    OBABEL_OUTPUTFORMAT_XYZ = (
+    OBABEL_OUTPUT_FORMAT_XYZ = (
         "-oxyz"  # sets the output format to "XYZ" (format in XTB/TM)
     )
     OBABEL_X = "-x"  # specifies generation options
@@ -1025,6 +1025,94 @@ class PantherEnum:
         raise ValueError("No changes allowed.")
 
 
+class KallistoEnum:
+
+    KALLISTO = "kallisto"  # Binary name.
+
+    # OPTIONS
+    SILENT = "--silent"
+    SHIFT = "--shift"  # INTEGER argument
+    HELP = "--help"  # Show this message and exit
+    HELP_IDENTIFICATION_STRING = "Show this message"
+
+    # COMMANDS
+    ALP = "alp"  # Static atomic polarizabilities in Bohr^3.
+    BONDS = "bonds"  # Get information about covalent bonding partner.
+    CNS = "cns"  # Atomic coordination numbers.
+    EEQ = "eeq"  # Electronegativity equilibration atomic partial charges.
+    EXS = (
+        "exs"  # Exchange a substrate within a transition metal complex with another...
+    )
+    LIG = "lig"  # Get all substructures (or ligands) that are bound to the center...
+    PROX = "prox"  # Atomic proximity shells.
+    RMS = "rms"  # Calculate the root mean squared deviation between two structures...
+    SORT = "sort"  # Sort input geoemtry according to connectivity.
+    STM = "stm"  # Calculate sterimol descriptors using kallisto van der Waals radii.
+    VDW = "vdw"  # Charge-dependent atomic van der Waals radii in Bohr.
+
+    # try to find the internal value and return
+    def __getattr__(self, name):
+        if name in self:
+            return name
+        raise AttributeError
+
+    # prohibit any attempt to set any values
+    def __setattr__(self, key, value):
+        raise ValueError("No changes allowed.")
+
+
+class JazzyEnum:
+    JAZZY = "jazzy"
+    HELP = "--help"
+    HELP_IDENTIFICATION_STRING = "Show this message"
+
+    # "vec" command
+    VEC = "vec"      # "generating properties" mode
+    VEC_OPT = "--opt"   # optimization
+    VEC_OPT_MMF94 = "MMF94"
+    VEC_OPT_MMF94S = "MMF94s"
+    VEC_OPT_UFF = "UFF"
+    VEC_STRENGHT_ONLY = "--strength_only"
+
+    # "vis" command
+    VIS = "vis"      # "generating graphics" mode
+    VIS_OPT = "--opt"
+    VIS_OPT_MMF94 = "MMF94"
+    VIS_OPT_MMF94S = "MMF94s"
+    VIS_OPT_UFF = "UFF"
+    VIS_FIG_SIZE = "--fig_size"    # Size of SVG image in pixels.  [default: 500, 500]
+    VIS_SDC_THRESHOLD = "--sdc_threshold"    # Treshold strength to depic Carbon donors. [default: 0.0]
+    VIS_SA_THRESHOLD = "--sa_threshold"    # Treshold strength to depic acceptors. [default: 0.0]
+    VIS_BASE64 = "--base64"
+    VIS_FLATTEN_MOLECULE = "--flatten_molecule"
+    VIS_HIGHLIGHT_ATOMS = "--highlight_atoms"
+    VIS_IGNORE_SDC = "--ignore_sdc"
+    VIS_IGNORE_SDX = "--ignore_sdx"
+    VIS_IGNORE_SA = "--ignore_sa"
+    VIS_HELP = "--help"
+
+    # result dictionary keys for "vec" command
+    RESULT_SDC = "sdc"
+    RESULT_SDX = "sdx"
+    RESULT_SA = "sa"
+    RESULT_DGA = "dga"
+    RESULT_DGP = "dgp"
+    RESULT_DGTOT = "dgtot"
+    RESULT_STATUS = "__status"
+    RESULT_STATUS_SUCCESS = "success"
+    RESULT_SMILES = "smiles"
+
+    # try to find the internal value and return
+    def __getattr__(self, name):
+        if name in self:
+            return name
+        raise AttributeError
+
+    # prohibit any attempt to set any values
+    def __setattr__(self, key, value):
+        raise ValueError("No changes allowed.")
+
+
 class ShaepEnum:
 
     SHAEP_EXECUTABLE = "shaep"
@@ -1352,10 +1440,12 @@ class StepPMXEnum:
     RUN_TYPE = "run_type"
     SIM_TYPES = "sim_types"
     EXEC_MODE = "exec_mode"
+    MDRUN_EXECUTABLE = "mdrun_executable"
 
     ABFE = "abfe"
     RBFE = "rbfe"
 
+    PREV_STEP = "previous_step"
     STRICT = "strict"
 
 
