@@ -3,12 +3,14 @@ from icolos.core.workflow_steps.autodockvina.docking import StepAutoDockVina
 from icolos.core.workflow_steps.autodockvina.target_preparation import (
     StepAutoDockVinaTargetPreparation,
 )
+from icolos.core.workflow_steps.calculation.jazzy import StepJazzy
+from icolos.core.workflow_steps.calculation.kallisto import StepKallisto
 from icolos.core.workflow_steps.ccdc.docking import StepGold
 from icolos.core.workflow_steps.calculation.electrostatics.esp_sim import StepEspSim
 from icolos.core.workflow_steps.calculation.feature_counter import StepFeatureCounter
 from icolos.core.workflow_steps.gromacs.do_dssp import StepGMXDoDSSP
 from icolos.core.workflow_steps.gromacs.mmpbsa import StepGMXmmpbsa
-from icolos.core.workflow_steps.cavity_explorer.mdpocket import StepMDpocket
+from icolos.core.workflow_steps.fpocket.mdpocket import StepMDpocket
 from icolos.core.workflow_steps.gromacs.trajcat import StepGMXTrjcat
 from icolos.core.workflow_steps.io.data_manipulation import StepDataManipulation
 from icolos.core.workflow_steps.schrodinger.fep_analysis import StepFepPlusAnalysis
@@ -63,6 +65,8 @@ class StepInitializationEnum:
         _SBE.STEP_CLUSTERING: StepClustering,
         _SBE.STEP_RMSFILTER: StepRMSFilter,
         _SBE.STEP_PANTHER: StepPanther,
+        _SBE.STEP_KALLISTO: StepKallisto,
+        _SBE.STEP_JAZZY: StepJazzy,
         _SBE.STEP_SHAEP: StepShaep,
         _SBE.STEP_PDB2GMX: StepGMXPdb2gmx,
         _SBE.STEP_EDITCONF: StepGMXEditConf,
